Description
============

Introduction
------------

The `shu` package provides a simple REST API on top of Airflow. It is
implemented as an plugin. To enable the API simply install `shu` in the
environment.

To explore the API refer your browser to the path `<airflow-server>/internal`,
where `<airflow-server>` is the host and port on which the Airflow webserver
listens.
